<?php

/**
 * Siempel functions and definitions
 *
 * @package Siempel
 * @since Siempel 0.1
 */

//Function Custom CSS
function siempel_custom_css() {
	wp_enqueue_style('siempel-style', get_stylesheet_uri() );
	$options = get_option('siempel_theme_options');
	$css = $options['css'];
	wp_add_inline_style( 'siempel-style', $css );
}
add_action( 'wp_enqueue_scripts', 'siempel_custom_css' );

//Function Remove Read More Link Scroll 
function siempel_remove_more_link_scroll( $link ) {
	$link = preg_replace( '|#more-[0-9]+|', '', $link );
	return $link;
}
add_filter( 'the_content_more_link', 'siempel_remove_more_link_scroll' ); 

//Adding Themes Options
require_once ( get_template_directory() . '/theme-options.php' );

//breadcrumbs
function siempel_breadcrumbs() {
$delimiter = '//';
$home = 'Home';
echo '<div xmlns:v="http://rdf.data-vocabulary.org/#">';
global $post;
echo ' <span typeof="v:Breadcrumb">
<a rel="v:url" property="v:title" href="'.home_url( '/' ).'">'.$home.'</a>
</span> ';
$cats = get_the_category();
if ($cats) {
foreach($cats as $cat) {
echo $delimiter . "<span typeof=\"v:Breadcrumb\">
<a rel=\"v:url\" property=\"v:title\" href=\"".get_category_link($cat->term_id)."\" >$cat->name</a>
</span>"; }
}
echo $delimiter . the_title(' <span>', '</span>', false);
echo '</div>';
}


/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since SIEMPEL 0.1
 */
if ( ! isset( $content_width ) )
	$content_width = 640; /* pixels */

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * @since SIEMPEL 0.1
 */
function siempel_setup() {
    /**
	 * Custom template tags for this theme.
	 */
	require( get_template_directory() . '/inc/template-tags.php' );
	/**
	 * Custom functions that act independently of the theme templates
	 */
	require( get_template_directory() . '/inc/extras.php' );
	/**
	 * Customizer additions
	 */
	require( get_template_directory() . '/inc/customizer.php' );
/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );
	/**
	 * Enable support for Post Thumbnails
	 */
	add_theme_support('post-thumbnails', array( 'post' ) );
	set_post_thumbnail_size( 150, 150, true );
	/**
	 * Enable support for Custom Background
	 */
	add_theme_support( 'custom-background' );
	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => 'Primary Menu',
	) );
	/**
	 * Enable support for Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );
} // siempel_setup
add_action( 'after_setup_theme', 'siempel_setup' );

//Register widgetized area and update sidebar with default widgets
function siempel_widgets_init() {
	register_sidebar( array(
		'name' => 'Footer 1 Sidebar',
		'id' => 'footer-1-sidebar',
		'description' => 'Appears as the Footer Sidebar.',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	register_sidebar( array(
		'name' => 'Footer 2 Sidebar',
		'id' => 'footer-2-sidebar',
		'description' => 'Appears as the Footer Sidebar.',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
}
add_action( 'widgets_init', 'siempel_widgets_init' );

//Enqueue scripts and styles
function siempel_scripts() {
	wp_enqueue_style( 'siempel-style', get_stylesheet_uri() );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/font-awesome.css' );
	wp_enqueue_script( 'siempel-plugins', get_template_directory_uri() . '/js/plugin.js', array( 'jquery' ), '20120206', true );
	wp_enqueue_script( 'siempel-small-menu', get_template_directory_uri() . '/js/small-menu.js', array( 'jquery' ), '20120206', true );
	wp_enqueue_script( 'siempel-nicescroll', get_template_directory_uri() . '/js/nicescroll.js', true );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	if ( is_singular() && wp_attachment_is_image() ) {
	wp_enqueue_script( 'keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}
}
add_action( 'wp_enqueue_scripts', 'siempel_scripts' );
?>